@@ -1,8 +1,9 @@
 package Gtk2::Ex::HyperTextView;
 
-our $VERSION = '0.18';
+our $VERSION = '0.20';
 
 use strict;
+use vars '%TAGS';
 use Gtk2;
 use Gtk2::Gdk::Keysyms;
 use Glib::Object::Subclass
@@ -52,6 +53,9 @@ Constructors.
 
 =cut
 
+*TAGS = \%Gtk2::Ex::HyperTextBuffer::TAGS;
+$TAGS{link} ||= [foreground => 'blue', underline => 'single'];
+
 # sub new() inherited from Glib::Object
 
 sub new_with_buffer {
@@ -67,7 +71,6 @@ sub INIT_INSTANCE {
 	
 	$self->{regular_cursor}  = Gtk2::Gdk::Cursor->new('xterm');
 	$self->{hand_cursor}     = Gtk2::Gdk::Cursor->new('hand2');
-	$self->{link_properties} = [foreground => 'blue', underline => 'single'];
 	$self->{hovering_over_link} = 0;
 	$self->{follow_on_enter} = 1;
 	
@@ -117,7 +120,7 @@ sub _create_link_tag {
 	my($self, $data) = @_;
 	
 	my $tag = $self->get_buffer->create_tag(
-		undef, @{$self->{link_properties}} );
+		undef, @{$TAGS{link}} );
 	$tag->{is_link}   = 1;
 	$tag->{link_data} = $data;
 
