@@ -2,12 +2,12 @@ package Zim::Formats::Wiki;
 
 use strict;
 no warnings;
+use Zim::Formats;
 
-our $VERSION = '0.17';
+our $VERSION = '0.21';
+our @ISA = qw/Zim::Formats/;
 
 # TODO: some tags can be nested: email links for example
-# TODO: header in the middle of a para doesn't get recognized
-
 
 =head1 NAME
 
@@ -20,6 +20,16 @@ It uses a wiki-style syntax to format plain text.
 
 FIXME more verbose description
 
+All format types are signified by double characters,
+this is done to prevent accidental formatting when the same
+characters are used normally in a text. For the same reason
+the strike character is '~' instead of '-' because '--' can
+occur in normal ascii text. In the regexes we try to always
+match the inner pair if more than two of these characters
+are encountered. (Thus if we see C<***bold***> we should match
+C<*(**bold**)*>.)
+
+
 =head1 METHODS
 
 =over 4
@@ -47,18 +57,23 @@ sub load_tree { # TODO whitelines between verbatim blocks should be preserved
 			push @tree, $class->parse_head($_);
 			$para = '';
 		}
+		#elsif (/^----+\s*$/) {
+		#	push @tree, $class->parse_para($para) if $para =~ /\S/;
+		#	push @tree, ['hr', {} ];
+		#	$para = '';
+		#}
 		else { $para .= $_ }
 	}
 	push @tree, $class->parse_para($para) if $para =~ /\S/;
 	
 	#use Data::Dumper; print STDERR Dumper \@tree;
-	return ['Document', {}, @tree];
+	return ['Page', {}, @tree];
 }
 
 sub parse_head { # parse a header
 	my ($class, $head) = @_;
 	chomp $head;
-	$head =~ s/^(==+)\s+(.*?)(\s+==+|\s*)$/$2/;
+	$head =~ s/^(==+)\s+(.*?)(\s+==+\s*|\s*)$/$2/;
 	my $level = 7 - length($1); # =X6 => head1, =X5 => head2 etc.
 	$level = 1 if $level < 1;
 	return ['head'.$level, {}, $head];
@@ -68,6 +83,7 @@ sub parse_para { # distinguise normal paras from verbatim paras
 	my ($class, $text) = @_;
 	return  $class->parse_Verbatim($text) unless $text =~ /^(?!\t|\s\s+)/m;
 	#$text =~ s/^\.//mg unless $text =~ /^(?!\.?\t|\.?\s\s+)/s;
+	$text =~ s/^(\s*)\*(\s+)/$1\x{2022}$2/mg;
 	return ['Para', {}, $class->parse_block($text)];
 }
 
@@ -78,7 +94,13 @@ sub parse_Verbatim { # parse pre formated paragraphs
 	return ['Verbatim', {}, $pre];
 }
 
-our @parser_subs = qw/parse_verbatim parse_links parse_images parse_styles parse_urls/;
+our @parser_subs = qw/
+	parse_verbatim
+	parse_links
+	parse_images
+	parse_styles
+	parse_urls
+/;
 
 sub parse_block { # parse a block of text
 	my ($class, @text) = @_;
@@ -94,7 +116,7 @@ sub parse_verbatim { # like parse_style() but needs to be done earlier
 	return	map {
 		unless ($i++ % 2) { $_ }
 		elsif (/^\'\'(.+)\'\'$/) { ['verbatim',  {}, $1] }
-	} split /(\'\'.+?\'\')/, $text;
+	} split /(\'\'(?!\').+?\'\')/, $text;
 }
 
 sub parse_links {
@@ -102,14 +124,15 @@ sub parse_links {
 	my $i = 0;
 	return
 		map   { ($i++ % 2) ? _parse_link($_) : $_ }
-		split m#(\[\[.+?\]\])#, $text;
+		split m#(\[\[(?!\[).+?\]\])#, $text;
 }
 
 sub _parse_link {
 	my $l = shift;
 	my $text;
-	if ($l =~ /^\[\[([^|]+)\|?(.*)\]\]$/) { # [[link]] or [[link|text]]
+	if ($l =~ /^\[\[([^|]*)\|?(.*)\]\]$/) { # [[link]] or [[link|text]]
 		($l, $text) = ($1, $2);
+		$l = $text unless length $l; # [[|link]] bug
 	}
 	if ($l =~ /^mailto:|^\S+\@\S+\.\w+$/) {
 		$text = $l unless length $text;
@@ -121,14 +144,15 @@ sub _parse_link {
 sub parse_urls {
 	my ($class, $text) = @_;
 	my $i = 0;
+	my $C = q/[^\s\"\<\>\']/; # limit the character class a bit
 	return
 		map   { ($i++ % 2) ? _parse_link($_) : $_ }
 		split m#(
-			\b\w[\w\+\-\.]+://  \S*\[\S+\](?:\S+[\w\/])? |
-			\b\w[\w\+\-\.]+://  \S+[\w\/]                |
-			\bmailto:\S+\@      \S*\[\S+\](?:\S+[\w/])?  |
-			\bmailto:\S+\@      \S+[\w/]                 |
-			\b\S+\@\S+\.\w+\b
+			\b\w[\w\+\-\.]+://  $C*\[$C+\](?:$C+[\w\/])? |
+			\b\w[\w\+\-\.]+://  $C+[\w\/]                |
+			\bmailto:$C+\@      $C*\[$C+\](?:$C+[\w/])?  |
+			\bmailto:$C+\@      $C+[\w/]                 |
+			\b$C+\@$C+\.\w+\b
 		)#x, $text;
 		# The host name in an uri can be "[hex:hex:..]" for ipv6
 		# but we do not want to match "[http://foo.org]"
@@ -145,19 +169,27 @@ sub parse_styles { # parse blocks of bold, italic and underline
 		elsif (/^\~\~(.+)\~\~$/) { ['strike',    {}, $1] }
 		elsif (/^\_\_(.+)\_\_$/) { ['underline', {}, $1] }
 	} split /(
-		\*\*.+?\*\* |
-		(?<!\:)\/\/.+?\/\/ |
-		\~\~.+?\~\~ |
-		__.+?__
+		\*\*(?!\*).+?\*\* |
+		(?<!\:)\/\/(?!\/).+?\/\/ |
+		\~\~(?!\~).+?\~\~ |
+		__(?!_).+?__
 	)/x, $text;
 }
 
 sub parse_images {
 	my ($class, $text) = @_;
 	my $i = 0;
-	return
+	my @parts =
 		map   { ($i++ % 2) ? ['image', {src => $_}] : $_ }
-		split /\{\{(.+?)\}\}/, $text;
+		split /\{\{(?!\{)(.+?)\}\}/, $text;
+	for my $p (@parts) {
+		next unless ref $p and $$p[0] eq 'image';
+		if ($$p[1]{src} =~ s/\?(\w+=\w+(?:&\w+=\w+)*)$//) {
+			my %arg = split /[=&]/, $1;
+			$$p[1]{$_} = $arg{$_} for keys %arg;
+		}
+	}
+	return @parts;
 }
 
 =item C<save_tree(IO, TREE, PAGE)>
@@ -187,6 +219,7 @@ sub _save_tree {
 	while (@$tree) {
 		my $node = shift @$tree;
 		unless (ref $node) {
+			$node =~ s/^(\s*)\x{2022}(\s+)/$1*$2/mg;
 			print $node;
 			next;
 		}
@@ -208,7 +241,10 @@ sub _save_tree {
 			print ( ('='x$n)." $text ".('='x$n)."\n" );
 		}
 		elsif ($tag eq 'image') {
-			print '{{'.$$meta{src}.'}}';
+			my $file = $$meta{src};
+			my @k = sort grep {$_ ne 'src'} keys %$meta;
+			$file .= '?' . join '&', map "$_=$$meta{$_}", @k if @k;
+			print '{{'.$file.'}}';
 		}
 		elsif ($tag eq 'link') {
 			my $to = $$meta{to};
@@ -264,7 +300,6 @@ modify it under the same terms as Perl itself.
 =head1 SEE ALSO
 
 L<Zim>,
-L<Zim::Repository>,
 L<Zim::Page>
 
 =cut
