@@ -2,14 +2,19 @@
 package Zim::GUI::Calendar;
 
 use strict;
-use vars '$AUTOLOAD';
+use vars qw/$CODESET/;
 use POSIX qw(strftime);
+use Encode;
 use Gtk2::Gdk::Keysyms;
+use Zim::Utils;
 use Zim::GUI::Component;
 
-our $VERSION = '0.18';
+our $VERSION = '0.23';
 our @ISA = qw/Zim::GUI::Component/;
 
+*CODESET = \$Zim::CODESET;
+$CODESET ||= 'utf8';
+
 =head1 NAME
 
 Zim::GUI::Calendar - Calendar widget for zim
@@ -36,12 +41,12 @@ sub init {
 	my $app = $self->{app};
 
 	$app->{settings}{cal_namespace} = 
-		$app->{repository}->resolve_page(
+		$app->{notebook}->resolve_page(
 			$app->{settings}{cal_namespace} )->name;
 	$app->{settings}{cal_namespace} =~ s/\:?$/:/;
 
 	my $dialog = Gtk2::Dialog->new(
-		'Calendar - Zim', $self->{app}{window},
+		__('Calendar'), $self->{app}{window}, #. dialog title
 	       	[qw/destroy-with-parent no-separator/],
 	);
 	$dialog->set_resizable(0);
@@ -52,11 +57,13 @@ sub init {
 	$dialog->vbox->set_spacing(5);
 	$self->{window} = $dialog;
 
-	my $fmt = $self->{app}{settings}{date_format};
-	my $label = Gtk2::Label->new(strftime($fmt, localtime));
+	my $fmt = __("%a %b %e %Y"); #. strftime format for current date - default suggested in perldoc localtime
+	my $label = Gtk2::Label->new( Encode::decode($CODESET,
+		strftime($fmt, localtime)) );
 	Glib::Timeout->add(60_000, sub {
 			return 0 unless $dialog->visible;
-			$label->set_text(strftime($fmt, localtime));
+			$label->set_text( Encode::decode($CODESET,
+					strftime($fmt, localtime)) );
 			return 1;
 		} );
 		# check once every minute whether the day didn't change
@@ -79,7 +86,7 @@ sub init {
 
 	my $hbox = Gtk2::HBox->new(0,0);
 	$dialog->vbox->pack_start($hbox, 0,1,0);
-	my $today_button = Gtk2::Button->new('_Today');
+	my $today_button = Gtk2::Button->new(__('_Today')); #. button
 	$hbox->pack_end($today_button, 0,1,0);
 	$today_button->signal_connect( clicked => sub {
 		my ($day, $month, $year) = (localtime)[3,4,5];
@@ -129,7 +136,7 @@ sub on_month_changed {
 	$year -= 1900;
 	my $string = strftime('%Y_%m', 0, 0, 0, $day, $month, $year);
 #	warn "Looking for $string in $nspace\n";
-	for ($app->{repository}->list_pages($nspace)) {
+	for ($app->{notebook}->list_pages($nspace)) {
 #		warn "$_\n";
 		/^$string\_(\d{2})/ or next;
 		$cal->mark_day($1);
