@@ -2,15 +2,42 @@ package Zim::GUI::Component;
 
 use strict;
 use vars qw/$AUTOLOAD/;
+use Gtk2;
 use Carp;
 use Encode;
-use File::BaseDir ();
+use File::BaseDir qw/xdg_data_home xdg_data_dirs xdg_data_files/;
+use Zim::Events;
+use Zim::Utils;
+  
+our $VERSION = '0.23';
 
-our $VERSION = '0.18';
+our @ISA = qw/Zim::Events/;
 
-($Zim::ICON) = File::BaseDir::xdg_data_files('pixmaps', 'zim.png');
+($Zim::ICON) = xdg_data_files('pixmaps', 'zim.png');
 warn "WARNING: Could not find 'zim.png', is \$XDG_DATA_DIRS set properly ?\n"
 	unless length $Zim::ICON;
+  
+{ # load all icons in pixmaps/zim
+ 	my @dirs = grep -d $_, map "$_/pixmaps/zim",
+ 		xdg_data_home, xdg_data_dirs;
+	my @files = ($Zim::ICON);
+ 	for my $d (@dirs) {
+		push @files, map $d.'/'.$_, Zim::File->list_dir($d);
+	}
+	return unless @files;
+
+	my $factory = Gtk2::IconFactory->new;
+	$factory->add_default;
+	for my $f (@files) {
+		my $pixbuf = Gtk2::Gdk::Pixbuf->new_from_file($f);
+		my $icon_set = Gtk2::IconSet->new_from_pixbuf($pixbuf);
+		my $n = $f;
+		$n =~ s/.*[\/\\]//;
+		$n =~ s/\..*//;
+		#warn "Icon: $n => $f\n";
+		$factory->add($n => $icon_set);
+	}
+}
 
 =head1 NAME
 
@@ -106,15 +133,15 @@ sub AUTOLOAD {
 
 =over 4
 
-=item C<add_actions($ACTIONS, $TYPE, $NAME)>
+=item C<add_actions(ACTIONS, TYPE, FUNCTION)>
 
 Add plain text action descriptions to the interface.
 
 TYPE can be C<undef>, "menu", "toggle" or "radio".
 
-NAME is an optonal group name. This is used to set a single
+FUNCTION is an optional function name. This is used to set a single
 callback for all actions. If NAME is not defined the callback
-for each action will be the name of the action.
+function for each action will be of the same name as the action.
 
 =cut
 
@@ -154,7 +181,7 @@ sub _add_radio_group {
 	my @actions;
 	for (@l) {
 		my @a = map {($_ eq '.') ? undef : $_} split /\t+/, $_;
-		push @a, $val++;
+		$a[5] = $val++;
 		push @actions, \@a;
 	}
 	#use Data::Dumper; warn "Actions (radio): ", Dumper \@actions;
@@ -230,6 +257,7 @@ sub actions_show_active {
 	my $self = shift;
 	$self->{_block_actions} = 1;
 	$self->actions_set_active(@_);
+	#while (Gtk2->events_pending) { Gtk2->main_iteration_do(0) }
 	$self->{_block_actions} = 0;
 }
 
@@ -294,16 +322,7 @@ Any arguments are passed on to the new process.
 
 sub exec_new_window {
 	my ($self, @args) = @_;
-	$self->_exec($^X, $0, @args);
-}
-
-sub _exec {
-	my ($self, @args) = @_;
-	warn "Executing: @args\n";
-	unless (fork) { # child process
-		exec @args;
-		exit 1; # just to be sure
-	}
+	Zim::Utils->run($^X, $0, @args);
 }
 
 =back
@@ -327,7 +346,7 @@ sub check_page_input {
 		# default parse_link(), not page dependent
 	return $l if $t eq 'page' and length $l;
 	$self->error_dialog(
-		"Not a valid page name: $name",
+		__("Not a valid page name: {name}", name => $name),
 		"Parsing gives type '$t' for page '$name'" );
 	return undef;
 }
@@ -411,12 +430,7 @@ Returns the dialog widget and a list with Gtk2::Entry objects.
 
 TITLE is the dialog title.
 
-FIELDS is an array ref giving the order of the input fields.
-
-DATA is a hash ref containing definitions of the input fields.
-The key is the name used in FIELDS, the value an array ref with a label text,
-a data type and a value.
-At the moment only the "string", "page", "file" and "dir" data types are treated special, all other will be ignored silently.
+FIELDS and DATA are used for the C<new_form()> method.
 
 TEXT, BUTTON_STOCK and BUTTON_TEXT are optional.
 
@@ -426,12 +440,13 @@ sub new_prompt {
 	my ($self, $title, $fields, $data, $stock, $string, $text) = @_;
 	
 	## Setup dialog
+	$title .= ' - Zim';
 	my $dialog = Gtk2::Dialog->new(
 		$title, $self->{app}{window},
 		[qw/modal destroy-with-parent no-separator/],
 		'gtk-cancel'  => 'cancel',
 	);
-	$dialog->set_resizable(0);
+	#$dialog->set_resizable(0);
 	#$dialog->vbox->set_border_width(12); # FIXME
 	$dialog->set_icon($self->{app}{window}->get_icon);
 	
@@ -450,13 +465,38 @@ sub new_prompt {
 		$dialog->vbox->add($align);
 	}
 	
-	## Generate table with input fields
+	my ($table, $entries) = $self->new_form($fields, $data, $dialog);
+	$dialog->vbox->add($table);
+
+	$dialog->show_all;
+	return $dialog, $entries;
+}
+
+=item C<new_form(FIELDS, DATA, DIALOG)>
+
+FIELDS is an array ref giving the order of the input fields.
+
+DATA is a hash ref containing definitions of the input fields.
+The key is the name used in FIELDS, the value an array ref with a label text,
+a data type and a value.
+At the moment only the "string", "page", "file" and "dir" data types are
+treated special, all other will be ignored silently.
+
+The "file" and "dir" types can have a 4th item being the dir to open
+when the value is empty and the "Browse" button is clicked.
+
+DIALOG is optional and will be used to connect signals.
+
+=cut
+
+sub new_form {
+	my ($self, $fields, $data, $dialog) = @_;
+
 	my $table = Gtk2::Table->new(scalar(@$fields), 2);
 	$table->set_border_width(5);
 	$table->set_row_spacings(5);
 	$table->set_col_spacings(12);
-	$dialog->vbox->add($table);
-	
+
 	my @entries;
 	for my $i (0 .. $#$fields) {
 		my @f = @{ $$data{$$fields[$i]} };
@@ -467,20 +507,19 @@ sub new_prompt {
 		
 		my $entry = Gtk2::Entry->new();
 		$entry->set_text($f[2]) if defined $f[2];
-		$entry->signal_connect(
-			activate => sub { $dialog->response('ok') } );
 		push @entries, $entry;
 		
-		$table->attach_defaults($align, 0,1, $i,$i+1);
+		$table->attach($align, 0,1, $i,$i+1, [],[], 0,0);
 
 		if ($f[1] eq 'file' or $f[1] eq 'dir') {
 			my $hbox = Gtk2::HBox->new(0,3);
 			$hbox->add($entry);
 
 			my $is_dir = ($f[1] eq 'dir');
-			my $button = Gtk2::Button->new('_Browse...');
+			my $button = Gtk2::Button->new(__('_Browse...')); #. button
 			$button->signal_connect( clicked => sub {
 				my $val = $entry->get_text();
+				$val = $f[3] if $val !~ /\S/;
 				$val = File::Spec->rel2abs('./___')
 					if $is_dir and ! length $val;
 					# force current dir instead of parent
@@ -504,8 +543,16 @@ sub new_prompt {
 		}
 	}
 	
-	$dialog->show_all;
-	return $dialog, \@entries;
+	for my $i (0 .. $#entries - 1) {
+		$entries[$i]->signal_connect(
+			activate => sub { $entries[$i+1]->grab_focus } );
+	}
+	if ($dialog) {
+		$entries[-1]->signal_connect(
+			activate => sub { $dialog->response('ok') } );
+	}
+
+	return ($table, \@entries);
 }
 
 =item C<set_page_completion(ENTRY)>
@@ -527,20 +574,20 @@ sub set_page_completion {
 
 sub _update_completion {
 	my ($entry, $self) = @_;
-	return unless $self->{app}{repository} and $self->{app}{page};
+	return unless $self->{app}{notebook} and $self->{app}{page};
 	my $ns = $entry->get_text;
 	$ns =~ s/[^:]+$//;
 	return if defined $entry->{_ns} and $entry->{_ns} eq $ns;
 	$entry->{_ns} = $ns;
 	
 	my $_ns = length($ns)
-		? $self->{app}{repository}->resolve_namespace($ns)
+		? $self->{app}{notebook}->resolve_namespace($ns)
 		: $self->{app}{page}->namespace() ;
 		#warn "Complete namespace: $_ns\n";
 	
 	my $model = $entry->get_completion->get_model;
 	$model->clear;
-	for ($self->{app}{repository}->list_pages($_ns)) {
+	for ($self->{app}{notebook}->list_pages($_ns)) {
 		s/_/ /g;
 		my $iter = $model->append();
 		$model->set($iter, 0 => $ns.$_);
@@ -586,6 +633,8 @@ sub prompt_question {
 	my ($self, $title, $type, $text, @buttons) = @_;
 	my $time = pop @buttons unless ref $buttons[-1];
 	
+	$title =~ s/(\s+\-)?\s*zim\s*$//i;
+	$title .= ' - Zim';
 	my $dialog = Gtk2::Dialog->new(
 		$title, $self->{app}{window},
 	       	[qw/modal destroy-with-parent no-separator/],
@@ -686,7 +735,7 @@ sub filechooser_dialog {
 	my ($self, $file, $dir, $title) = @_;
 	
 	my $dialog;
-	$title ||= $dir ? 'Select Folder' : 'Select File' ;
+	$title ||= $dir ? __('Select Folder') : __('Select File') ; #. dialog title
 	# if (Gtk2->CHECK_VERSION(2, 4, 0) and $Gtk2::VERSION >= 1.040) {
 	$dialog = Gtk2::FileChooserDialog->new(
 		$title, $self->{app}{window}, 'open',
