@@ -3,11 +3,12 @@ package Zim::GUI::ExportDialog;
 use strict;
 use Gtk2;
 use File::BaseDir qw/xdg_data_files xdg_data_dirs xdg_data_home/;
-use Zim::Selection;
+use Zim::Utils;
 use Zim::GUI::Component;
+use Zim::Selection;
 #use Zim::Formats;
 
-our $VERSION = '0.18';
+our $VERSION = '0.23';
 our @ISA = qw/Zim::GUI::Component/;
 
 =head1 NAME
@@ -32,10 +33,10 @@ Present the dialog.
 sub show {
 	my $self = shift;
 	return $self->{dialog}->present if defined $self->{dialog};
-	$self->{app}->save_page || return;
+	$self->{app}->SaveIfModified or return;
 
 	my $dialog = Gtk2::Dialog->new(
-		"Export page - Zim", $self->{app}{window},
+		__("Export page"), $self->{app}{window}, #. dialog title
 	       	[qw/destroy-with-parent no-separator/],
 		'gtk-help'   => 'help',
 		'gtk-cancel' => 'cancel',
@@ -46,7 +47,7 @@ sub show {
 	
 	# Page range
 	my $frame = Gtk2::Frame->new;
-	my $label = Gtk2::Label->new('<b>Pages</b>');
+	my $label = Gtk2::Label->new('<b>'.__('Pages').'</b>'); #. group label
 	$label->set_use_markup(1);
 	$frame->set_label_widget($label);
 	$dialog->vbox->add($frame);
@@ -55,14 +56,16 @@ sub show {
 	$vbox->set_border_width(12);
 	$frame->add($vbox);
 	
-	my $radio1 = Gtk2::RadioButton->new_with_mnemonic(undef, '_All');
+	my $radio1 = Gtk2::RadioButton->new_with_mnemonic(
+		undef, __('_All') ); #. radio button
 	my $rgroup = $radio1->get_group;
 	$vbox->add($radio1);
 
 	my $hbox = Gtk2::HBox->new(0, 5);
 	$vbox->add($hbox);
 	
-	my $radio2 = Gtk2::RadioButton->new_with_mnemonic($rgroup, '_Page:');
+	my $radio2 = Gtk2::RadioButton->new_with_mnemonic(
+		$rgroup, __('_Page').':' ); #. radio button
 	$hbox->pack_start($radio2, 0,1,0);
 	
 	my $page_entry = Gtk2::Entry->new();
@@ -70,7 +73,7 @@ sub show {
 	$page_entry->set_sensitive(0);
 	$hbox->pack_start($page_entry, 0,1,0);
 
-	my $recurs_box = Gtk2::CheckButton->new_with_label('Recursive');
+	my $recurs_box = Gtk2::CheckButton->new_with_label(__('Recursive')); #. check box
 	$recurs_box->set_active(1);
 	$recurs_box->set_sensitive(0);	
 	$vbox->add($recurs_box);
@@ -83,7 +86,7 @@ sub show {
 	
 	# Output
 	$frame = Gtk2::Frame->new;
-	$label = Gtk2::Label->new('<b>Output</b>');
+	$label = Gtk2::Label->new('<b>'.__('Output').'</b>'); #. group label
 	$label->set_use_markup(1);
 	$frame->set_label_widget($label);
 	$dialog->vbox->add($frame);
@@ -95,7 +98,7 @@ sub show {
 	$frame->add($table);
 	
 	my $i;
-	for (qw/Format Template/, '', 'Output dir') {
+	for (__('Format'), __('Template'), '', __('Output dir'), __('Index page')) { #. label input field
 		if (length $_) {
 			my $label = Gtk2::Label->new($_.':');
 			my $align = Gtk2::Alignment->new(0,0.5, 0,0);
@@ -105,7 +108,7 @@ sub show {
 		$i++;
 	}
 
-	my $conf = $self->{app}{repository}->config;
+	my $conf = $self->{app}{notebook}->config;
 	
 	my $combo1 = Gtk2::ComboBox->new_text();
 	my @formats = qw/Html Txt2Tags/;
@@ -122,7 +125,7 @@ sub show {
 
 	my $entry2 = Gtk2::Entry->new;
 	$table->attach_defaults($entry2, 1,2, 2,3);
-	my $button2 = Gtk2::Button->new('_Browse...');
+	my $button2 = Gtk2::Button->new(__('_Browse...')); #. button
 	$button2->signal_connect(clicked => sub {
 		my $t = $self->filechooser_dialog();
 		$entry2->set_text($t);
@@ -133,7 +136,7 @@ sub show {
 	$table->attach_defaults($entry3, 1,2, 3,4);
 	$entry3->set_text($$conf{export_dir});
 	$entry3->signal_connect(activate => sub { $dialog->response('ok') });
-	my $button3 = Gtk2::Button->new('_Browse...');
+	my $button3 = Gtk2::Button->new(__('_Browse...')); #. button
 	$button3->signal_connect(clicked => sub {
 		my $dir = $entry3->get_text;
 		$dir = $self->filechooser_dialog($dir, 'DIR');
@@ -141,16 +144,21 @@ sub show {
 	} );
 	$table->attach_defaults($button3, 2,3, 3,4);
 	
+	my $entry4 = Gtk2::Entry->new;
+	$table->attach_defaults($entry4, 1,2, 4,5);
+	$entry4->set_text( $$conf{export_index} || 'index' );
+
 	my $fill_combo2 = sub {
 		my $format = _get_active_text($combo1);
 		for (reverse 0 .. $combo2_items) { $combo2->remove_text($_) }
 		$templates = Zim::Formats->list_templates($format);
 		for (sort keys %$templates) {
+			next if /^[_\W]/; # skip "_New" etc.
 			if (/^default$/i) { $combo2->prepend_text($_) }
 			else              { $combo2->append_text($_)  }
 		}
 		$combo2_items = scalar keys %$templates;
-		$combo2->append_text('other...');
+		$combo2->append_text(__('other...')); #. item in dropdown menu
 		$combo2->set_active(0);
 		my $other = ($combo2_items == 0);
 		$entry2->set_sensitive($other);
@@ -176,7 +184,7 @@ sub show {
 	}
 
 	$frame = Gtk2::Frame->new;
-	$label = Gtk2::Label->new('<b>Media</b>');
+	$label = Gtk2::Label->new('<b>'.__('Media').'</b>'); #. group label
 	$label->set_use_markup(1);
 	$frame->set_label_widget($label);
 	$dialog->vbox->add($frame);
@@ -185,14 +193,17 @@ sub show {
 	$vbox->set_border_width(12);
 	$frame->add($vbox);
 	
-	my $media_radio1 = Gtk2::RadioButton->new_with_mnemonic(undef, '_Relative linked');
+	my $media_radio1 = Gtk2::RadioButton->new_with_mnemonic(
+		undef, __('_Relative linked') ); #. radio button
 	$rgroup = $media_radio1->get_group;
 	$vbox->add($media_radio1);
 
-	my $media_radio2 = Gtk2::RadioButton->new_with_mnemonic($rgroup, '_Absolute linked');
+	my $media_radio2 = Gtk2::RadioButton->new_with_mnemonic(
+		$rgroup, __('_Absolute linked') ); #. radio button
 	$vbox->add($media_radio2);
 
-	my $media_radio3 = Gtk2::RadioButton->new_with_mnemonic($rgroup, '_Copy files');
+	my $media_radio3 = Gtk2::RadioButton->new_with_mnemonic(
+		$rgroup, __('_Copy files')); #. radio button
 	$vbox->add($media_radio3);
 	my $media_r = ($$conf{export_media} eq 'absolute') ? $media_radio2 :
 	              ($$conf{export_media} eq 'copy')     ? $media_radio3 :
@@ -237,21 +248,23 @@ sub show {
 			dir      => $entry3->get_text,
 			template => $template,
 			media    => $media,
+			index    => $entry4->get_text
 		);
-		@$conf{qw/export_dir export_format export_media/}
-			= @opts{qw/dir format media/};
+		$$conf{'export_'.$_} = $opts{$_}
+			for qw/dir format media index/;
 		$$conf{'export_template'} = $tn;
 		$dialog->destroy;
 		$self->{dialog} = undef;
 		my ($bar, $label);
 		($dialog, $bar, $label) = $self->new_progress_bar(
-			"Export page - Zim", "Exporting page 1" );
+			__("Export page"), #. dialog title
+			__("Exporting page {number}", number => 0) ); #. progress bar label
 		my $continue = 1;
 		$dialog->signal_connect(response => sub {$continue = 0});
 		my $i = 1;
 		$opts{callback} = sub {
 			$bar->pulse;
-			$label->set_text('Exporting page ' . $i++);
+			$label->set_text(__("Exporting page {number}", number => $i++)); #. progress bar label
 			while (Gtk2->events_pending) { Gtk2->main_iteration_do(0) }
 			return $continue;
 		};
@@ -259,12 +272,12 @@ sub show {
 		eval {
 			my $o = { resolve => 1, recurse => $recurs_box->get_active() };
 			my $s = Zim::Selection->new(
-				$self->{app}{repository}, $o, @pages);
+				$self->{app}{notebook}, $o, @pages);
 			$s->export(\%opts);
 		};
 		$self->error_dialog($@) if $@;
 
-		$self->{app}{repository}->save(); # save settings
+		$self->{app}{notebook}->save(); # save settings
 		
 		last;
 	}
