@@ -2,8 +2,9 @@ package Zim::GUI::FindReplaceDialog;
 
 use strict;
 use Gtk2;
+use Zim::Utils;
 
-our $VERSION = '0.18';
+our $VERSION = '0.23';
 
 =head1 NAME
 
@@ -43,7 +44,7 @@ sub show {
 	
 	## Setup dialog
 	my $dialog = Gtk2::Dialog->new(
-		'Find and Replace - Zim', $self->{app}{window},
+		__('Find and Replace'), $self->{app}{window}, #. dialog title
 		[qw/destroy-with-parent no-separator/],
 		'gtk-help'  => 'help',
 		'gtk-close' => 'close',
@@ -62,19 +63,19 @@ sub show {
 
 	# Find entry
 	my $align = Gtk2::Alignment->new(0,0.5, 0,0);
-	$align->add( Gtk2::Label->new('Find what:') );
+	$align->add( Gtk2::Label->new(__('Find what').':') ); #. input label
 	$vbox->add( $align );
 	my $find_entry = Gtk2::Entry->new;
 	$vbox->add( $find_entry );
 
-	my $case = Gtk2::CheckButton->new('Match c_ase');
+	my $case = Gtk2::CheckButton->new(__('Match c_ase')); #. check box
 	$vbox->add($case);
-	my $word = Gtk2::CheckButton->new('Whole _word');
+	my $word = Gtk2::CheckButton->new(__('Whole _word')); #. check box
 	$vbox->add($word);
 
 	# Replace entry
 	$align = Gtk2::Alignment->new(0,0.5, 0,0);
-	$align->add( Gtk2::Label->new('Replace with:') );
+	$align->add( Gtk2::Label->new(__('Replace with').':') ); #. input label
 	$vbox->add( $align );
 	my $replace_entry = Gtk2::Entry->new;
 	$vbox->add( $replace_entry );
@@ -84,7 +85,8 @@ sub show {
 	my $bbox = Gtk2::VButtonBox->new;
 	$hbox->add($bbox);
 	
-	my $next_b = $self->{app}->new_button('gtk-go-forward', '_Next');
+	my $next_b = $self->{app}->new_button(
+		'gtk-go-forward', __('_Next') ); #. button
 	$next_b->signal_connect(clicked => sub {
 		my $query = $find_entry->get_text;
 		my @opt = map $_->get_active, $case, $word;
@@ -94,7 +96,8 @@ sub show {
 	$find_entry->signal_connect( activate => sub { $next_b->clicked } );
 	$bbox->add($next_b);
 
-	my $prev_b = $self->{app}->new_button('gtk-go-back', '_Previous');
+	my $prev_b = $self->{app}->new_button(
+		'gtk-go-back', __('_Previous') ); #. button
 	$prev_b->signal_connect(clicked => sub {
 		my $query = $find_entry->get_text;
 		my @opt = map $_->get_active, $case, $word;
@@ -103,7 +106,8 @@ sub show {
 	} );
 	$bbox->add($prev_b);
 
-	my $repl_b = $self->{app}->new_button('gtk-find-and-replace', '_Replace');
+	my $repl_b = $self->{app}->new_button(
+		'gtk-find-and-replace', __('_Replace') ); #. button
 	$repl_b->signal_connect(clicked => sub {
 		my $query = $find_entry->get_text;
 		my $string = $replace_entry->get_text;
@@ -113,7 +117,7 @@ sub show {
 	} );
 	$bbox->add($repl_b);
 
-	my $repl_all_b = Gtk2::Button->new('Replace all');
+	my $repl_all_b = Gtk2::Button->new(__('Replace _all') ); #. button
 	$repl_all_b->signal_connect(clicked => sub {
 		my $query = $find_entry->get_text;
 		my $string = $replace_entry->get_text;
