@@ -3,8 +3,10 @@ package Zim::GUI::PreferencesDialog;
 use strict;
 use File::BaseDir qw/xdg_data_files xdg_data_dirs xdg_data_home/;
 use Gtk2;
+use Gtk2::SimpleList;
+use Zim::Utils;
 
-our $VERSION = '0.18';
+our $VERSION = '0.23';
 
 =head1 NAME
 
@@ -37,65 +39,69 @@ Present the dialog.
 =cut
 
 my %Labels = ( # setting => [label, tooltip]
-	date_format => [
-		'Date format',
-		"Default format for dates",
-	],
 	browser => [
-		'Web browser',
-		"Application to open urls",
+		__('Web browser'), #. pref. label
+		__("Application to open urls"), #. pref. tooltip
 	],
 	file_browser => [
-		'File browser',
-		"Application to open directories",
+		__('File browser'), #. pref. label
+		__("Application to open directories"), #. pref. tooltip
 	],
 	email_client => [
-		'Email client',
-		"Application to compose email",
+		__('Email client'), #. pref. label
+		__("Application to compose email"), #. pref. tooltip
+	],
+	text_editor => [
+		__('Text editor'), #. pref. label
+		__("Application to edit text files"), #. pref. tooltip
 	],
 	user_name => [
-		'User name',
-		"Your name; this can be used in export templates",
+		__('User name'), #. pref. label
+		__("Your name; this can be used in export templates"), #. pref. tooltip
+	],
+	follow_new_link => [
+		__('Follow new link'), #. pref. label
+		__("Creating a new link directly opens the page"), #. pref. tooltip
 	],
-#	follow_new_link => [
-#		'Follow new link',
-#		"Creating a new link directly opens the page",
-#	],
 	ro_cursor => [
-		'Show cursor for read-only',
-		"Show the cursor even when you can not edit the page. This is useful for keyboard based browsing.",
+		__('Show cursor for read-only'), #. pref. label
+		__("Show the cursor even when you can not edit the page. This is useful for keyboard based browsing."), #. pref. tooltip
 	],
 	tearoff_menus => [
-		'Tearoff menus',
-		"Add 'tearoff' strips to the menus",
+		__('Tearoff menus'), #. pref. label
+		__("Add 'tearoff' strips to the menus"), #. pref. tooltip
 	],
 	use_camelcase => [
-		'Auto-link CamelCase',
-		"Automaticly link CamelCase words when you type",
+		__('Auto-link CamelCase'), #. pref. label
+		__("Automaticly link CamelCase words when you type"), #. pref. tooltip
 	],
 	use_linkfiles => [
-		'Auto-link files',
-		"Automatically link file names when you type",
+		__('Auto-link files'), #. pref. label
+		__("Automatically link file names when you type"), #. pref. tooltip
 	],
 	use_utf8_ent => [
-		'Auto-format entities',
-		"Use autoformatting to type special characters",
+		__('Auto-format entities'), #. pref. label
+		__("Use autoformatting to type special characters"), #. pref. tooltip
 	],
 	backsp_unindent => [
-		'use "Backspace" to un-indent',
-		"Use the \"Backspace\" key to un-indent bullet lists (Same as \"Shift-Tab\")",
+		__('Use "Backspace" to un-indent'), #. pref. label
+		__("Use the \"Backspace\" key to un-indent bullet lists (Same as \"Shift-Tab\")"), #. pref. tooltip
 	],
 	use_autoselect => [
-       		'Auto-select words',
-		"Automaticly select the current word when you toggle the format",
+       		__('Auto-select words'), #. pref. label
+		__("Automaticly select the current word when you toggle the format"), #. pref. tooltip
 	],
 	follow_on_enter => [
-		'Use "Enter" to follow links',
-		"Use the \"Enter\" key to follow links. If disabled you still can use \"Alt-Enter\"",
+		__('Use "Enter" to follow links'), #. pref. label
+		__("Use the \"Enter\" key to follow links. If disabled you still can use \"Alt-Enter\""), #. pref. tooltip
 	],
 	use_ctrl_space => [
-		'Use "Ctrl-Space" to switch focus',
-		"Use the \"Ctrl-Space\" key combo to switch focus between text and side pane. If disabled you can still use \"Alt-Space\".",
+		__('Use "Ctrl-Space" to switch focus'), #. pref. label
+		__("Use the \"Ctrl-Space\" key combo to switch focus between text and side pane. If disabled you can still use \"Alt-Space\"."), #. pref. tooltip
+	],
+	expand_tree => [
+		__('Expand side pane'), #. pref. label
+		__("Start the side pane with the whole tree expanded."), #. pref. tooltip
 	],
 );
 
@@ -103,7 +109,7 @@ sub show {
 	my $self = shift;
 	my $app = $self->{app};
 	my $dialog = Gtk2::Dialog->new(
-		"Preferences - Zim", $app->{window},
+		__("Preferences"), $app->{window}, #. dialog title
 	       	[qw/destroy-with-parent no-separator/],
 		'gtk-help'   => 'help',
 		'gtk-cancel' => 'cancel',
@@ -149,14 +155,14 @@ sub show {
 	## General tab
 	my $vbox = Gtk2::VBox->new(0,5);
 	$vbox->set_border_width(5);
-	$tabs->append_page($vbox, 'General');
+	$tabs->append_page($vbox, __('General')); #. tab label
 	
 	my @settings = qw/
 		user_name
-		date_format
 		browser
 		file_browser
 		email_client
+		text_editor
 	/;
 	my $table = Gtk2::Table->new(scalar(@settings), 2);
 	$table->set_row_spacings(5);
@@ -172,14 +178,15 @@ sub show {
 	## Interface tab
 	$vbox = Gtk2::VBox->new(0,5);
 	$vbox->set_border_width(5);
-	$tabs->append_page($vbox, 'Interface');
+	$tabs->append_page($vbox, __('Interface')); #. tab label
 	
 	@settings = qw/
 		follow_on_enter
+		follow_new_link
 		use_ctrl_space
-		backsp_unindent
 		ro_cursor
 		tearoff_menus
+		expand_tree
 	/;
 	for (@settings) {
 		$vbox->pack_start($_checkbox->($_), 0,1,0);
@@ -192,7 +199,8 @@ sub show {
 	$i = 0;
 
 	# Font button
-	my $use_font = Gtk2::CheckButton->new_with_label('Use custom font');
+	my $use_font = Gtk2::CheckButton->new_with_label(
+		__('Use custom font') ); #. check box
 	$table->attach_defaults($use_font, 0,2, $i,$i+1);
 	$i++;
 	$use_font->set_active($$settings{textfont});
@@ -220,14 +228,14 @@ sub show {
 	## Editing tab
 	$vbox = Gtk2::VBox->new(0,5);
 	$vbox->set_border_width(5);
-	$tabs->append_page($vbox, 'Editing');
+	$tabs->append_page($vbox, __('Editing')); #. tab label
 	@settings = qw/
 		use_camelcase
 		use_linkfiles
 		use_utf8_ent
 		use_autoselect
+		backsp_unindent
 	/;
-		#follow_new_link
 	$table = Gtk2::Table->new(scalar(@settings), 1);
 	$table->set_row_spacings(5);
 	$table->set_col_spacings(12);
@@ -241,12 +249,11 @@ sub show {
 	## Plugins tab
 	$vbox = Gtk2::VBox->new(0,5);
 	$vbox->set_border_width(5);
-	$tabs->append_page($vbox, 'Plugins');
+	$tabs->append_page($vbox, __('Plugins')); #. tab label
 
 	my $label = Gtk2::Label->new();
 	$label->set_markup(
-		"<i>You need to restart the application\n".
-		"for plugin changes to take effect.</i>");
+		'<i>'.__("You need to restart the application\nfor plugin changes to take effect.").'</i>');
 	$vbox->pack_start($label, 0,1,0);
 	my @plugins;
 	my @plugged = split /,/, $$settings{plugins};
@@ -255,20 +262,24 @@ sub show {
 		next unless -d $dir;
 		for my $f (Zim::File->list_dir($dir)) {
 			next unless $f =~ s/\.pl$//;
-			next if grep {$$_[0] eq $f} @plugins;
+			next if grep {$$_[1] eq $f} @plugins;
 			my $bit = grep {$_ eq $f} @plugged;
-			push @plugins, [$f, $bit];
+			push @plugins, [$bit, $f];
 		}
 	}
-	@plugins = sort {$$a[0] cmp $$b[0]} @plugins;
-	
-	for (@plugins) {
-		my $box = Gtk2::CheckButton->new_with_label($$_[0]);
-		$box->set_active($$_[1]);
-		$vbox->pack_start($box, 0,1,0);
-		push @$_, $box;
-	}
+	@plugins = sort {$$a[1] cmp $$b[1]} @plugins;
 	
+	my $plugin_list = Gtk2::SimpleList->new(
+		__('Enabled') => 'bool',   #. header plugin list
+		__('Name')    => 'text' ); #. header plugin list
+	@{$plugin_list->{data}} = @plugins;
+	my $win = Gtk2::ScrolledWindow->new();
+	$win->set_policy('automatic', 'automatic');
+	$win->set_shadow_type('in');
+	$win->add($plugin_list);
+	$vbox->add($win);
+
+
 	## Show it all
 	$dialog->show_all;
 	while ($_ = $dialog->run) {
@@ -287,8 +298,6 @@ sub show {
 			#warn "$_ = $$settings{$_}\n";
 		}
 
-		$$settings{date_format} = '%A %d/%m/%Y'
-			unless defined $$settings{date_format};
 		$app->{ui}->set_add_tearoffs($$settings{tearoff_menus});
 			# FIXME signal for this ?
 		$app->PageView->on_show_cursor();
@@ -297,12 +306,11 @@ sub show {
 		## FIXME signal for this ##
 		$app->PageView->{htext}{follow_on_enter} =
 			$$settings{follow_on_enter};
-		$app->{repository}{date_format} = $$settings{date_format};
-		$app->{repository}{user_name} = $$settings{user_name};
+		$app->{notebook}{user_name} = $$settings{user_name};
 		## ##
 		
 		# set plugins
-		@plugged = map $$_[0], grep $$_[2]->get_active, @plugins;
+		@plugged = map $$_[1], grep $$_[0], @{$plugin_list->{data}};
 		$$settings{plugins} = join ',', @plugged;
 
 		last;
