@@ -3,20 +3,17 @@ package Zim::GUI::SearchDialog;
 use strict;
 use Gtk2;
 use Gtk2::SimpleList;
+use Zim::Utils;
 
-our $VERSION = '0.18';
+our $VERSION = '0.23';
 
 =head1 NAME
 
 Zim::GUI::SearchDialog - simple module
 
-=head1 SYNOPSIS
-
-FIXME simple code example
-
 =head1 DESCRIPTION
 
-FIXME descriptve text
+This module contains the search dialog for zim.
 
 =head1 METHODS
 
@@ -43,7 +40,7 @@ sub show {
 	
 	## Setup dialog
 	my $dialog = Gtk2::Dialog->new(
-		'Search - Zim', $self->{app}{window},
+		__('Search'), $self->{app}{window}, #. dialog title
 		[qw/destroy-with-parent no-separator/],
 		'gtk-help'   => 'help',
 		'gtk-close' => 'close',
@@ -59,7 +56,7 @@ sub show {
 	my $hbox = Gtk2::HBox->new(0,5);
 	$vbox->add($hbox);
 
-	$hbox->add( Gtk2::Label->new('Search:') );
+	$hbox->add( Gtk2::Label->new(__('Search').':') ); #. input
 	my $string_entry = Gtk2::Entry->new();
 	$string_entry->signal_connect(
 		activate => sub { $dialog->response('ok') } );
@@ -68,9 +65,11 @@ sub show {
 	$find_button->signal_connect(clicked => sub { $dialog->response('ok') } );
 	$hbox->add($find_button);
 
-	my $case_box = Gtk2::CheckButton->new_with_mnemonic('Match c_ase');
+	my $case_box = Gtk2::CheckButton->new_with_mnemonic(
+		__('Match c_ase') ); #. check box
 	$vbox->add($case_box);
-	my $word_box = Gtk2::CheckButton->new_with_mnemonic('Whole _word');
+	my $word_box = Gtk2::CheckButton->new_with_mnemonic(
+		__('Whole _word') ); #. check box
 	$vbox->add($word_box);
 	
 	my $swindow = Gtk2::ScrolledWindow->new();
@@ -78,7 +77,9 @@ sub show {
 	$swindow->set_shadow_type('in');
 	$dialog->vbox->add($swindow);
 	
-	my $list = Gtk2::SimpleList->new(Page => 'text', Rank => 'int');
+	my $list = Gtk2::SimpleList->new(
+		__('Page') => 'text',   #. header search results
+		__('Rank') => 'int'  ); #. header search results
 	$list->get_column(0)->set_expand(1);
 	$list->get_column(0)->set_sort_column_id(0);
 	$list->get_column(1)->set_sort_column_id(1);
@@ -108,7 +109,7 @@ sub show {
 		} ;
 		return unless $$query{string} =~ /\S/;
 		if ($$query{string} =~ /:/) { # back links - FIXME does not belong here
-			my $page = $self->{app}{repository}->resolve_page($$query{string});
+			my $page = $self->{app}{notebook}->resolve_page($$query{string});
 			return unless $page;
 			@{$list->{data}} = map [$_, 1], $page->list_backlinks();
 		}
@@ -120,7 +121,7 @@ sub show {
 					Gtk2->main_iteration_do(0);
 				}
 			};
-			$self->{app}{repository}->search($query, $callback);
+			$self->{app}{notebook}->search($query, $callback);
 		}
 	} );
 
