@@ -4,9 +4,10 @@ use strict;
 use vars '$AUTOLOAD';
 use Gtk2;
 use Gtk2::Gdk::Keysyms;
+use Zim::Utils;
 use Zim::GUI::Component;
 
-our $VERSION = '0.18';
+our $VERSION = '0.23';
 our @ISA = qw/Zim::GUI::Component/;
 
 =head1 NAME
@@ -16,7 +17,7 @@ Zim::GUI::TreeView - Page index widgets
 =head1 DESCRIPTION
 
 This module contains the widgets to display the index 
-of a zim repository as a TreeView.
+of a zim notebook as a TreeView.
 
 =head1 METHODS
 
@@ -34,7 +35,7 @@ Method called by the constructor.
 
 =cut
 
-my ($k_left, $k_right) = @Gtk2::Gdk::Keysyms{qw/Left Right/};
+my ($k_left, $k_right, $k_esc) = @Gtk2::Gdk::Keysyms{qw/Left Right Escape/};
 
 sub init { # called by new()
 	my $self = shift;
@@ -85,15 +86,17 @@ sub init { # called by new()
 
 	# drag-n-drop stuff
 	$tree_view->enable_model_drag_source(
-		'button1-mask', ['link', 'copy', 'move'],
+		'button1-mask', ['link'],
 		['text/x-zim-page-list', [], 0] );
 	$tree_view->signal_connect_swapped(
 		drag_data_get => \&on_drag_data_get, $self);
 	$tree_view->enable_model_drag_dest(
-		['link', 'copy', 'move'],
+		['link'],
 		['text/x-zim-page-list', [], 0] );
 	$tree_view->signal_connect_swapped(
 		drag_data_received => \&on_drag_data_received, $self);
+	$tree_view->signal_connect(drag_begin => sub { $$self{drag_lock} = 1 });
+	$tree_view->signal_connect(drag_end => sub { $$self{drag_lock} = 0 });
 
 
 	$self->{widget} = $self->{tree_view};
@@ -105,7 +108,7 @@ sub on_drag_data_get { # we are drag source
 	return unless $info == 0; # text/x-zim-page-list
 
 	my $rep = $self->{app}{name};
-	warn "BUG: no repository name set!" unless length($rep);
+	warn "BUG: no notebook name set!" unless length($rep);
 	my @pages = map "$rep?$_", grep length($_), map {$self->path2page($_)}
 		$self->{tree_view}->get_selection->get_selected_rows;
 	#warn "drag data: @pages";
@@ -116,6 +119,7 @@ sub on_drag_data_get { # we are drag source
 
 sub on_drag_data_received { # we are drag target
 	my ($self, $context, $x, $y, $selection_data, $info, $time) = @_;
+	#warn "!! drag_action:".$context->action.' ('.join(', ', $context->actions).")\n";
 	return unless $info == 0; # text/x-zim-page-list
 
 	my $data = $selection_data->data;
@@ -132,7 +136,7 @@ sub on_drag_data_received { # we are drag target
 	$page =~ /^(.*?)\?(.*:)(.+)/ or return;
 	my ($rep, $ns, $basename) = ($1, $2, $3);
 	if ($rep ne $$self{app}{name} or $ns eq $node_ns) {
-		# either from a different repository
+		# either from a different notebook
 		# or in the same namespace
 		# => failure
 		$context->finish(0, 1, $time);
@@ -183,6 +187,15 @@ sub on_key_press_event { # some extra keybindings for the treeview
 		my $page = $self->get_selected;
 		$self->{app}->PageView->InsertLink($page, $page, 'NO_ASK');
 	}
+	elsif ($key eq '\\') { # Collapse all
+		$tree_view->collapse_all;
+	}
+	elsif ($key eq '*') { # Expand all
+		$tree_view->expand_all;
+	}
+	elsif ($val == $k_esc) { # Escape - close side pane
+		$$self{app}->TPane(0) if $$self{app}{_pane_visible} == -1;
+	}
 	else { return 0 }
 	return 1;
 }
@@ -204,6 +217,9 @@ sub on_button_release_event {
 
 sub on_row_activated { # load a page when clicked or entered
 	my $self = pop;
+	return if $$self{drag_lock};
+		# Sometimes this signal is triggered while in a drag
+		# operation. Bug in Gtk? Not sure.
 	my ($tree_view, $path) = @_;
 	my $page = $self->path2page($path);
 	$self->{app}->load_page($page)
@@ -303,7 +319,7 @@ sub load_index { # TODO remove this from Zim.pm and PageView.pm
 
 =item C<list_pages(NAMESPACE)>
 
-Wrapper around C<< Zim::Repository->list_pages() >> to fill the tree.
+Wrapper around C<< Zim::Store->list_pages() >> to fill the tree.
 
 =cut
 
@@ -313,7 +329,7 @@ sub list_pages {
 	# TODO check for existing children
 	$namespace =~ s/:*$//;
 	my $model = $self->{tree_store};
-	my $repository = $self->{app}{repository};
+	my $notebook = $self->{app}{notebook};
 	my @queue = ([$namespace, $iter]);
 	my $sub = sub {
 		unless (@queue) {
@@ -324,20 +340,27 @@ sub list_pages {
 		}
 		my ($ns, $node) = @{ shift @queue };
 		#warn "list_pages: $ns\n";
-		for my $p ($repository->list_pages($ns)) {
+		my $child;
+		for my $p ($notebook->list_pages($ns)) {
 			#warn "\t$p\n";
 			my $is_dir = ($p =~ s/:+$//);
 			my $name = $p;
 			$name =~ s/_/ /g;
-			my $child = $model->append($node);
+			$child = $model->append($node);
 			$model->set($child, 0 => $name, 1 => $ns.':'.$p);
 				# base_name, name
 			push @queue, [$ns.':'.$p, $child] if $is_dir; # recurse
 		}
+
+		# expand tree into this namespace (child is last child)
+		$self->{tree_view}->expand_to_path($model->get_path($child))
+			if $child and $self->{app}{settings}{expand_tree};
+		
 		return 1;
 	} ;
 	warn "# Start scanning tree\n";
-	$self->{app}->push_status('Scanning tree ...', 'TreeView');
+	$self->{app}->push_status(
+		__('Scanning tree ...'), 'TreeView'); #. status bar info
 	Glib::Idle->add($sub);
 }
 
