@@ -1,10 +1,10 @@
 package Zim::Selection;
 
 use strict;
-use Zim::Repository;
+use Zim::Store;
 
-our $VERSION = '0.18';
-our @ISA = qw/Zim::Repository/;
+our $VERSION = '0.23';
+our @ISA = qw/Zim::Store/;
 
 =head1 NAME
 
@@ -20,7 +20,7 @@ This class is used to manage selections of pages.
 The pages are still asociates with a repository, this object can
 be used to call operations on a sub-set of a repository.
 
-Inherits from L<Zim::Repository>.
+Inherits from L<Zim::Store>.
 
 =head1 METHODS
 
@@ -28,7 +28,7 @@ Inherits from L<Zim::Repository>.
 
 =item C<new($REPOSITORY, \%OPT, @PAGES)>
 
-Constructor. REPOSITORY should be an object of class L<Zim::Repository>
+Constructor. REPOSITORY should be an object of class L<Zim> or L<Zim::Store>
 and is the object used to look up the pages in the selection.
 
 The OPT hash can contain several options. Curently only "recurse" and
@@ -153,9 +153,12 @@ sub export {
 		die "For exporting you need to provide at least".
 		    "arguments 'dir' and 'format'.\n"
 		    if grep {! length $_} @$opt{qw/dir format/} ;
-		eval "use Zim::Repository::Files"; die $@ if $@;
-		$target = Zim::Repository::Files->new(
+
+		Zim::File->make_dir($$opt{dir});
+		eval "use Zim::Store::Files"; die $@ if $@;
+		$target = Zim::Store::Files->new(
 				dir => $$opt{dir}, format => $$opt{format} ) ;
+
 		my $template = $$opt{template};
 		if ($template) {
 			$template = Zim::Formats->lookup_template($$opt{format}, $template)
@@ -176,8 +179,14 @@ sub export {
 		warn "# Exporting to pre-set repository\n";
 		$target = $opt;
 	}
+
 	$target->{user_name} = $self->{rep}{user_name};
-	
+	if ($$opt{index}) {
+		$target->{_index} = $target->resolve_name($$opt{index});
+		die "Could not resolve index page"
+			if ! $target->{_index};
+	}
+
 	my $index = '';
 	my @items = (undef, undef, undef);
 	my $code = sub {
@@ -204,14 +213,15 @@ sub export {
 	$self->foreach($code);
 	$code->(undef) if $items[2]; # flush last page
 
-	$self->_write_index($target, $index)
-		unless defined $$opt{index} and ! $$opt{index} ;
+	$self->_write_index($target, $index) if $$opt{index} ;
 	warn "# Done Exporting\n";
 }
 
 sub _write_index { # write a index page for export
 	my ($self, $target, $index) = @_;
-	my $page = $target->get_page(':index');
+
+	my $page = $target->get_page($target->{_index});
+	$page->delete if $page->exists; # prevent mtime check etc.
 
 	# convert index to wiki list
 	# TODO use parse tree list items
@@ -224,24 +234,25 @@ sub _write_index { # write a index page for export
 			next if $match and defined $ns[$depth]
 				and $ns[$depth] eq $parts[$depth];
 			$match = 0;
+			my $name = $parts[$depth];
+			$name =~ s/_/ /g;
 			push @list,
 				("\t"x$depth)."\x{2022} ",
-				['bold', {}, $parts[$depth]], "\n" ;
+				['bold', {}, $name], "\n" ;
 		}
 		@ns = @parts;
 		
 		my $depth = $#ns;
+		my $name = $parts[-1];
+		$name =~ s/_/ /g;
 		push @list,
 			("\t"x$depth)."\x{2022} ",
-			['link', {to => $page}, $parts[-1]], "\n" ;
+			['link', {to => $page}, $name], "\n" ;
 	}
 
 	warn "# Writing index\n";
-	$page->set_parse_tree( 
-		['Page', {}, 
-			['head1', {}, "Document index"],
-			['Para', {}, @list],
-		] ) ;
+	$page->{_is_index}=1; # FIXME hack
+	$page->set_parse_tree( ['Page', {}, ['Para', {}, @list] ] ) ;
 }
 
 1;
