@@ -1,11 +1,17 @@
 package Zim::Template;
 
 use strict;
-use UNIVERSAL qw/isa/;
+use vars qw/$CODESET/;
 use Carp;
+use UNIVERSAL qw/isa/;
+use POSIX qw(strftime);
+use Encode;
 use Zim::File;
 
-our $VERSION = '0.17';
+our $VERSION = '0.21';
+
+*CODESET = \$Zim::CODESET;
+$CODESET ||= 'utf8';
 
 =head1 NAME
 
@@ -27,14 +33,11 @@ Simple templating module. Template syntax is as follows:
 
 	[% var %]
 	[% hash.key %]
+	[% strftime("%c", var) %]
 	[% IF var %] .. [$ END %]
 	[% IF var %] .. [% ELSE %] ... [$ END %]
 	[% FOREACH name = var %] ... [% name %] ... [% END %]
 
-Trying to keep syntax consistent with the template toolkit.
-Thus we can plug in the template toolkit for the more heavy-duty
-work later when needed. Think of this module as a "template toolkit light".
-
 The template is tokenized and kept in memory. Thus this module is most
 efficient when you want to dump many pages with one template.
 
@@ -76,7 +79,7 @@ sub _die { die sprintf "\%s in template '\%s' at line \%u\n", $_[1], $_[0]{name}
 sub _open_io { # FIXME doesn't this belong in Zim::File ?
 	my ($self, $io, $mode, $set_name) = @_;
 
-	if (! ref $io or isa $io, 'Zim::File') { # file name
+	if (! ref $io or isa $io, 'Zim::File') { # file name or object
 		my $f = ref($io) ? $io : Zim::File->new($io);
 		$self->{name} = $f->path if $set_name;
 		return $f->open($mode);
@@ -86,6 +89,7 @@ sub _open_io { # FIXME doesn't this belong in Zim::File ?
 		$mode = ($mode eq 'w') ? '>' : '<' ;
 		my $fh;
 		open $fh, $mode, $io;
+		binmode $fh, ':utf8' unless $] < 5.008;
 		return $fh;
 	}
 	else { # assume it to be an IO handle
@@ -141,22 +145,29 @@ sub _tokenize { # Parses text and builds a token tree
 				push @tokens, $t;
 			}
 			elsif ($expr =~ /^(?:SET\s+)?([\w\.]+)\s*=\s*(\S+)$/) {
-				my $t = {
+				push @tokens, {
 					token => 'SET',
 					line => $count,
 					var => $1,
 					val => $2,
 				};
-				push @tokens, $t;
 			}
 			elsif ($expr =~ /^(?:GET\s+)?([\w\.]+)$/) {
 				$line ||= "\n" unless $is_block; # reverse beautification
-				my $t = {
+				push @tokens, {
 					token => 'GET',
 					line => $count,
 					var => $1
 				};
-				push @tokens, $t;
+			}
+			elsif ($expr =~ /^([\w\.]+)\((.*?)\)$/) {
+				$line ||= "\n" unless $is_block; # reverse beautification
+				push @tokens, {
+					token => 'CALL',
+					line => $count,
+					function => $1,
+					args => _parse_args($2),
+				};
 			}
 			else { $self->_die("Unknown expression '$expr'") }
 		}
@@ -166,6 +177,24 @@ sub _tokenize { # Parses text and builds a token tree
 	return \@tokens;
 }
 
+my %special = (n => "\n", t => "\t");
+
+sub _parse_args {
+	# parse a string into an argument list
+	# all arguments are strings by defnition, NO CODE EVAL!
+	my $string = shift;
+	return [] unless $string =~ /\S/;
+	my @args;
+	while ($string =~ s/^\s*((["'])(\\.|[^'"])*\2|[^\s,]+)\s*,?//) {
+		#warn ">>$1<< >>$string<<\n";
+		my $arg = $1;
+		$arg =~ s/^(['"])(.*)\1$/$2/; # remove quotes
+		$arg =~ s/\\(.)/$special{$1}||$1/eg; # remove escapes
+		push @args, $arg;
+	}
+	return \@args;
+}
+
 sub _collect { # Collect template content till next (not nested) "[% END %]"
 	my ($self, $line, $in, $count) = @_;
 	my ($blob, $stack) = ('', 0);
@@ -189,7 +218,7 @@ sub _collect { # Collect template content till next (not nested) "[% END %]"
 	return ($blob, $line, $count);
 }
 
-=item C<process(\%DATA => IO)>
+=item C<< process(\%DATA => IO) >>
 
 Wraps C<set_data()> and C<output()> in one call.
 
@@ -211,6 +240,7 @@ Set the data hash.
 sub set_data {
 	my ($self, $data) = @_;
 	croak "DATA is not a hash" unless isa $data, 'HASH';
+	#use Data::Dumper; warn Dumper $data;
 	$self->{data} = $data;
 }
 
@@ -266,6 +296,16 @@ sub _output { # Processes a token tree
 					$self->_output($fh, $$t{loop_branch});
 				}
 			}
+			elsif ($$t{token} eq 'CALL') {
+				die "TODO: allow other functions except strftime"
+					unless $$t{function} eq 'strftime';
+				my $fmt = $$t{args}[0] || "%c";
+				my $time = $$t{args}[1]
+					? $self->_var(@$t{'var', 'line'})
+					: time;
+				print $fh Encode::decode($CODESET,
+					strftime($fmt, localtime $time) );
+			}
 			else { die "BUG: unknown token: $$t{token}" }
 		}
 		else { print $fh $t }
