@@ -1,6 +1,6 @@
-my $app = Zim->current();
+my $app = Zim::GUI->current();
 
-eval 'use Zim::Components::Spell';
+eval 'use Zim::GUI::Spell';
 if ($@) {
 	$app->error_dialog(
 		"Failed to load Spell plugin,\n".
@@ -9,7 +9,7 @@ if ($@) {
 	return 1;
 }
 
-my $spell = Zim::Components::Spell->new(app => $app);
+my $spell = Zim::GUI::Spell->new(app => $app);
 $app->add_object(Spell => $spell);
 
 1;
