@@ -3,8 +3,9 @@ my $app = Zim::GUI->current();
 eval 'use Zim::GUI::TrayIcon';
 if ($@) {
 	$app->error_dialog(
-		"Failed to load TrayIcon plugin,\n".
-		"do you have Gtk2::TrayIcon installed ?", $@);
+		"Failed to load TrayIcon plugin.\n".
+		"You either need gtk+ >= 2.10 or you".
+		"need to have Gtk2::TrayIcon installed.", $@);
 	$app->unplug('TrayIcon');
 	return 1;
 }
